Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(340)

Unified Diff: chromeos/dbus/shill_client_unittest_base.h

Issue 10915106: Renaming instances of "flimflam" with "shill", now that we're only (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Upload after merge Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/shill_client_helper.cc ('k') | chromeos/dbus/shill_client_unittest_base.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/shill_client_unittest_base.h
diff --git a/chromeos/dbus/flimflam_client_unittest_base.h b/chromeos/dbus/shill_client_unittest_base.h
similarity index 91%
rename from chromeos/dbus/flimflam_client_unittest_base.h
rename to chromeos/dbus/shill_client_unittest_base.h
index 68ac59ca11e97b391d12eb2fabd6182ea902eaed..1c56a17d3bb719d835f2bc5b7916bf3861ff16e8 100644
--- a/chromeos/dbus/flimflam_client_unittest_base.h
+++ b/chromeos/dbus/shill_client_unittest_base.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROMEOS_DBUS_FLIMFLAM_CLIENT_UNITTEST_BASE_H_
-#define CHROMEOS_DBUS_FLIMFLAM_CLIENT_UNITTEST_BASE_H_
+#ifndef CHROMEOS_DBUS_SHILL_CLIENT_UNITTEST_BASE_H_
+#define CHROMEOS_DBUS_SHILL_CLIENT_UNITTEST_BASE_H_
#include <string>
@@ -11,7 +11,7 @@
#include "base/memory/scoped_ptr.h"
#include "base/message_loop.h"
#include "chromeos/dbus/dbus_method_call_status.h"
-#include "chromeos/dbus/flimflam_client_helper.h"
+#include "chromeos/dbus/shill_client_helper.h"
#include "dbus/mock_bus.h"
#include "dbus/mock_object_proxy.h"
#include "dbus/object_proxy.h"
@@ -32,8 +32,8 @@ class MessageReader;
namespace chromeos {
-// A class to provide functionalities needed for testing Flimflam D-Bus clients.
-class FlimflamClientUnittestBase : public testing::Test {
+// A class to provide functionalities needed for testing Shill D-Bus clients.
+class ShillClientUnittestBase : public testing::Test {
public:
// A mock Closure.
class MockClosure {
@@ -51,12 +51,12 @@ class FlimflamClientUnittestBase : public testing::Test {
~MockErrorCallback();
MOCK_METHOD2(Run, void(const std::string& error_name,
const std::string& error_mesage));
- FlimflamClientHelper::ErrorCallback GetCallback();
+ ShillClientHelper::ErrorCallback GetCallback();
};
- explicit FlimflamClientUnittestBase(const std::string& interface_name,
+ explicit ShillClientUnittestBase(const std::string& interface_name,
const dbus::ObjectPath& object_path);
- virtual ~FlimflamClientUnittestBase();
+ virtual ~ShillClientUnittestBase();
virtual void SetUp() OVERRIDE;
virtual void TearDown() OVERRIDE;
@@ -162,4 +162,4 @@ class FlimflamClientUnittestBase : public testing::Test {
} // namespace chromeos
-#endif // CHROMEOS_DBUS_FLIMFLAM_CLIENT_UNITTEST_BASE_H_
+#endif // CHROMEOS_DBUS_SHILL_CLIENT_UNITTEST_BASE_H_
« no previous file with comments | « chromeos/dbus/shill_client_helper.cc ('k') | chromeos/dbus/shill_client_unittest_base.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698